@@ -3,11 +3,13 @@
 """
 import sys
 from os.path import dirname, abspath
+import logging
 
 from django.conf import settings as django_settings
 
 from tests import settings
 
+logging.basicConfig(level=logging.DEBUG, format='%(asctime)s %(name)-12s %(levelname)-8s %(message)s', datefmt='%d.%m %H:%M:%S')
 
 if not django_settings.configured:
     django_settings.configure(
